@@ -3,12 +3,12 @@ function()
 {
   write("        ,.-.,                                                                                    ", file="")
   write("      .`     `.                                                                                  ", file="")
-  write("     /.-., ,.-.`            *       *                                 ****      **       ****    ", file="")
-  write("   .`    .`.    `.     ***   *     *   ***    ****   ****    *     * *    *   *  *      *    *   ", file="")
-  write("  / `.  /   `.  / `  *     *  *   *  *     * *    * *    *    *   *      *       *          *    ", file="")
-  write(" |    ',_____,'    | ******   *   *  ******  *    * *    *     * *      *        *         *     ", file="")
-  write(" `.     `   /     /  *         * *   *       *    * *    *     * *    *          *       *       ", file="")
-  write("   ',    '_'    ,'    *****     *     *****  *    * *    *      *    ****** * ******* * *******  ", file="")
+  write("     /.-., ,.-.`            *       *                                 ****      **       *****   ", file="")
+  write("   .`    .`.    `.     ***   *     *   ***    ****   ****    *     * *    *   *  *      *     *  ", file="")
+  write("  / `.  /   `.  / `  *     *  *   *  *     * *    * *    *    *   *      *       *           *   ", file="")
+  write(" |    ',_____,'    | ******   *   *  ******  *    * *    *     * *      *        *           *   ", file="")
+  write(" `.     `   /     /  *         * *   *       *    * *    *     * *    *          *      *     *  ", file="")
+  write("   ',    '_'    ,'    *****     *     *****  *    * *    *      *    ****** * ******* *  *****   ", file="")
   write("     `'-'` `'-'`                                                                                 ", file="")
   write("\n#####################", file="")
   write("# eVenn Quick Start #", file="")
